<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Antono Vasiljev <esperanto.minsk ĈE tut.by>
 * @author Felipe Castro <fefcas@yahoo.com.br>
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <bogi@uea.org>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Redakti la paĝon';
$lang['btn_source']            = 'Montri fontan tekston';
$lang['btn_show']              = 'Montri paĝon';
$lang['btn_create']            = 'Krei paĝon';
$lang['btn_search']            = 'Serĉi';
$lang['btn_save']              = 'Konservi';
$lang['btn_preview']           = 'Antaŭrigardi';
$lang['btn_top']               = 'Supren';
$lang['btn_newer']             = '<< pli freŝe';
$lang['btn_older']             = 'malpli freŝe >>';
$lang['btn_revs']              = 'Malnovaj revizioj';
$lang['btn_recent']            = 'Freŝaj ŝanĝoj';
$lang['btn_upload']            = 'Alŝuti';
$lang['btn_cancel']            = 'Rezigni';
$lang['btn_index']             = 'Indekso';
$lang['btn_secedit']           = 'Redakti';
$lang['btn_login']             = 'Ensaluti';
$lang['btn_logout']            = 'Elsaluti';
$lang['btn_admin']             = 'Administri';
$lang['btn_update']            = 'Aktualigi';
$lang['btn_delete']            = 'Forigi';
$lang['btn_back']              = 'Retroiri';
$lang['btn_backlink']          = 'Retroligoj';
$lang['btn_backtomedia']       = 'Retroiri al elekto de dosiero';
$lang['btn_subscribe']         = 'Aliĝi al paĝaj modifoj';
$lang['btn_profile']           = 'Aktualigi profilon';
$lang['btn_reset']             = 'Rekomenci';
$lang['btn_resendpwd']         = 'Sendi novan pasvorton';
$lang['btn_draft']             = 'Redakti skizon';
$lang['btn_recover']           = 'Restarigi skizon';
$lang['btn_draftdel']          = 'Forigi skizon';
$lang['btn_revert']            = 'Restarigi';
$lang['btn_register']          = 'Registriĝi';
$lang['btn_apply']             = 'Apliki';
$lang['btn_media']             = 'Medio-administrilo';
$lang['btn_deleteuser']        = 'Forigi mian konton';
$lang['btn_img_backto']        = 'Iri reen al %s';
$lang['btn_mediaManager']      = 'Rigardi en aŭdvidaĵ-administrilo';
$lang['loggedinas']            = 'Ensalutinta kiel';
$lang['user']                  = 'Uzant-nomo';
$lang['pass']                  = 'Pasvorto';
$lang['newpass']               = 'Nova pasvorto';
$lang['oldpass']               = 'Konfirmu la nunan pasvorton';
$lang['passchk']               = 'plian fojon';
$lang['remember']              = 'Rememoru min';
$lang['fullname']              = 'Kompleta nomo';
$lang['email']                 = 'Retpoŝto';
$lang['profile']               = 'Uzanto-profilo';
$lang['badlogin']              = 'Pardonu, uzant-nomo aŭ pasvorto estis erara.';
$lang['badpassconfirm']        = 'Pardonu, la pasvorto malĝustis';
$lang['minoredit']             = 'Etaj modifoj';
$lang['draftdate']             = 'Lasta konservo de la skizo:';
$lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, tial la tuta paĝo estas reŝargita.';
$lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
$lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam ekzistas.';
$lang['regsuccess']            = 'La uzanto kreiĝis kaj la pasvorto sendiĝis per retpoŝto.';
$lang['regsuccess2']           = 'La uzanto kreiĝis.';
$lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvolu informi administranton pri tio!';
$lang['regbadmail']            = 'Entajpita retpoŝta adreso ŝajnas ne valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
$lang['regbadpass']            = 'La du pasvortoj ne samas, bonvolu provi refoje.';
$lang['regpwmail']             = 'Via DokuWiki-pasvorto';
$lang['reghere']               = 'Se vi ne havas konton, vi povas akiri ĝin';
$lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
$lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
$lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesata.';
$lang['profchanged']           = 'La profilo de la uzanto sukcese aktualiĝis.';
$lang['profnodelete']          = 'Tiu ĉi vikio ne subtenas forigo de uzantoj';
$lang['profdeleteuser']        = 'Forigi aliĝon';
$lang['profdeleted']           = 'Via uzant-aliĝo estis forigata de tiu ĉi vikio';
$lang['profconfdelete']        = 'Mi deziras forigi mian aliĝon de tiu ĉi vikio. <br/> Tiu ĉi ago ne povos esti malfarata.';
$lang['profconfdeletemissing'] = 'Konfirmilo ne estas markita';
$lang['pwdforget']             = 'Ĉu vi forgesis vian pasvorton? Prenu novan';
$lang['resendna']              = 'Tiu ĉi vikio ne ebligas resendon de la pasvortoj.';
$lang['resendpwd']             = 'Sendi novan pasvorton al';
$lang['resendpwdmissing']      = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
$lang['resendpwdnouser']       = 'Pardonu, tiu uzanto ne troveblas en nia datumbazo.';
$lang['resendpwdbadauth']      = 'Pardonu, tiu aŭtentiga kodo ne validas. Certiĝu, ke vi uzis la kompletan konfirmigan ligilon.';
$lang['resendpwdconfirm']      = 'Konfirmiga ligilo sendiĝis per retpoŝto.';
$lang['resendpwdsuccess']      = 'Via nova pasvorto sendiĝis per retpoŝto.';
$lang['license']               = 'Krom kie rekte indikite, enhavo de tiu ĉi vikio estas publikigita laŭ la jena permesilo:';
$lang['licenseok']             = 'Rimarku: redaktante tiun ĉi paĝon vi konsentas publikigi vian enhavon laŭ la jena permesilo:';
$lang['searchmedia']           = 'Serĉi dosiernomon:';
$lang['searchmedia_in']        = 'Serĉi en %s';
$lang['txt_upload']            = 'Elektu dosieron por alŝuti';
$lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
$lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
$lang['maxuploadsize']         = 'Alŝuto maks. %s po dosiero.';
$lang['lockedby']              = 'Nune ŝlosita de';
$lang['lockexpire']            = 'Ŝlosado ĉesos je';
$lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempokontrolon de la ŝlosado, premu la butonon "Antaŭrigardi".';
$lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
Ĉu vi certe volas daŭrigi la procezon?';
$lang['js']['searchmedia']     = 'Serĉi dosierojn';
$lang['js']['keepopen']        = 'Tenu la fenestron malferma dum elekto';
$lang['js']['hidedetails']     = 'Kaŝi detalojn';
$lang['js']['mediatitle']      = 'Ligilaj agordoj';
$lang['js']['mediadisplay']    = 'Ligila tipo';
$lang['js']['mediaalign']      = 'Poziciigo';
$lang['js']['mediasize']       = 'Bildgrandeco';
$lang['js']['mediatarget']     = 'Ligila celo';
$lang['js']['mediaclose']      = 'Fermi';
$lang['js']['mediainsert']     = 'Enmeti';
$lang['js']['mediadisplayimg'] = 'Montri la bildon.';
$lang['js']['mediadisplaylnk'] = 'Montri nur la ligilon.';
$lang['js']['mediasmall']      = 'Malgranda versio';
$lang['js']['mediamedium']     = 'Meza versio';
$lang['js']['medialarge']      = 'Granda versio';
$lang['js']['mediaoriginal']   = 'Origina versio';
$lang['js']['medialnk']        = 'Ligilo al detala paĝo';
$lang['js']['mediadirect']     = 'Rekta ligilo al la origino';
$lang['js']['medianolnk']      = 'Neniu ligilo';
$lang['js']['medianolink']     = 'Ne ligi la bildon';
$lang['js']['medialeft']       = 'Meti la bildon maldekstren.';
$lang['js']['mediaright']      = 'Meti la bildon dekstren.';
$lang['js']['mediacenter']     = 'Meti la bildon mezen.';
$lang['js']['medianoalign']    = 'Ne uzi poziciigon.';
$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en "Microsoft Internet Explorer".\nVi ankoraŭ povas kopii kaj almeti la ligilon.';
$lang['js']['linkwiz']         = 'Ligil-Asistanto';
$lang['js']['linkto']          = 'Ligilo al:';
$lang['js']['del_confirm']     = 'Ĉu vere forigi elektita(j)n ero(j)n?';
$lang['js']['restore_confirm'] = 'Ĉu vere restarigi ĉi tiun version?';
$lang['js']['media_diff']      = 'Rigardu la diferencojn:';
$lang['js']['media_diff_both'] = 'Flankon apud flanko';
$lang['js']['media_diff_opacity'] = 'Unu super la alia';
$lang['js']['media_diff_portions'] = 'Ŝovilo';
$lang['js']['media_select']    = 'Elektu dosierojn...';
$lang['js']['media_upload_btn'] = 'Alŝuto';
$lang['js']['media_done_btn']  = 'Finita';
$lang['js']['media_drop']      = 'Demetu ĉi-tien por alŝuti';
$lang['js']['media_cancel']    = 'forigi';
$lang['js']['media_overwrt']   = 'Anstataûi ekzistantajn dosierojn';
$lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: ';
$lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
$lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
$lang['fileupload']            = 'Alŝuto de aŭdvidaĵa dosiero';
$lang['uploadsucc']            = 'Alŝuto sukcesis';
$lang['uploadfail']            = 'Alŝuto malsukcesis. Ĉu eble estas problemoj pro permes-atributoj?';
$lang['uploadwrong']           = 'Rifuzita alŝuto. Tiu ĉi dosiersufikso estas malpermesata!';
$lang['uploadexist']           = 'La dosiero jam ekzistas. Nenio estas farita.';
$lang['uploadbadcontent']      = 'La alŝutita enhavo ne kongruas al la sufikso %s.';
$lang['uploadspam']            = 'La alŝutaĵo blokiĝis de kontraŭspama vortlisto.';
$lang['uploadxss']             = 'La alŝutajo blokiĝis pro ebla malica enhavo.';
$lang['uploadsize']            = 'La alŝutita dosiero estis tro granda. (maks. %s)';
$lang['deletesucc']            = 'La dosiero "%s" forigiĝis.';
$lang['deletefail']            = '"%s" ne povis esti forigita - kontrolu permes-atributojn.';
$lang['mediainuse']            = 'La dosiero "%s" ne forigiĝis - ĝi ankoraŭ estas uzata.';
$lang['namespaces']            = 'Nomspacoj';
$lang['mediafiles']            = 'Disponeblaj dosieroj';
$lang['accessdenied']          = 'Vi ne rajtas vidi tiun paĝon.';
$lang['mediausage']            = 'Uzu jenan sintakson por referenci tiun ĉi dosieron:';
$lang['mediaview']             = 'Rigardi originalan dosieron';
$lang['mediaroot']             = 'ĉefo (root)';
$lang['mediaupload']           = 'Alŝutu dosieron al la kuranta nomspaco tien ĉi. Por krei subnomspacojn, antaŭmetu ilin al via "Alŝuti kiel" dosiernomo, disigigante per dupunktoj (:).';
$lang['mediaextchange']        = 'La dosiersufikso ŝanĝis de .%s al .%s!';
$lang['reference']             = 'Referencoj por';
$lang['ref_inuse']             = 'La dosiero ne povas esti forigita, ĉar ĝi ankoraŭ estas uzata de jenaj paĝoj:';
$lang['ref_hidden']            = 'Kelkaj referencoj estas en paĝoj, kiujn vi ne rajtas legi';
$lang['hits']                  = 'Trafoj';
$lang['quickhits']             = 'Trafoj trovitaj en paĝnomoj';
$lang['toc']                   = 'Enhavtabelo';
$lang['current']               = 'aktuala';
$lang['yours']                 = 'Via versio';
$lang['diff']                  = 'Montri diferencojn el la aktuala versio';
$lang['diff2']                 = 'Montri diferencojn inter la elektitaj revizioj';
$lang['difflink']              = 'Ligilo al kompara rigardo';
$lang['diff_type']             = 'Rigardi malsamojn:';
$lang['diff_inline']           = 'Samlinie';
$lang['diff_side']             = 'Apude';
$lang['diffprevrev']           = 'Antaŭa revizio';
$lang['diffnextrev']           = 'Sekva revizio';
$lang['difflastrev']           = 'Lasta revizio';
$lang['diffbothprevrev']       = 'Sur ambaŭ flankoj antaŭa revizio';
$lang['diffbothnextrev']       = 'Sur ambaŭ flankoj sekva revizio';
$lang['line']                  = 'Linio';
$lang['breadcrumb']            = 'Paŝoj';
$lang['youarehere']            = 'Vi estas ĉi tie';
$lang['lastmod']               = 'Lastaj ŝanĝoj';
$lang['by']                    = 'de';
$lang['deleted']               = 'forigita';
$lang['created']               = 'kreita';
$lang['restored']              = 'malnova revizio restarigita (%s)';
$lang['external_edit']         = 'ekstera redakto';
$lang['summary']               = 'Bulteno de ŝanĝoj';
$lang['noflash']               = 'La <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> necesas por montri tiun ĉi enhavon.';
$lang['download']              = 'Elŝuti eltiraĵon';
$lang['tools']                 = 'Iloj';
$lang['user_tools']            = 'Uzantaj iloj';
$lang['site_tools']            = 'Retejaj iloj';
$lang['page_tools']            = 'Paĝaj iloj';
$lang['skip_to_content']       = 'al la enhavo';
$lang['sidebar']               = 'Flanka strio';
$lang['mail_newpage']          = 'paĝo aldonita:';
$lang['mail_changed']          = 'paĝo modifita:';
$lang['mail_subscribe_list']   = 'ŝanĝitaj paĝoj en nomspaco:';
$lang['mail_new_user']         = 'Nova uzanto:';
$lang['mail_upload']           = 'dosiero alŝutita:';
$lang['changes_type']          = 'Rigardi ŝanĝojn de';
$lang['pages_changes']         = 'Paĝoj';
$lang['media_changes']         = 'Mediaj dosieroj';
$lang['both_changes']          = 'Ambaû - paĝojn kaj mediajn dosierojn';
$lang['qb_bold']               = 'Dika teksto';
$lang['qb_italic']             = 'Dekliva teksto';
$lang['qb_underl']             = 'Substrekita teksto';
$lang['qb_code']               = 'Koduma teksto';
$lang['qb_strike']             = 'Trastrekita teksto';
$lang['qb_h1']                 = 'Titolo de 1-a nivelo';
$lang['qb_h2']                 = 'Titolo de 2-a nivelo';
$lang['qb_h3']                 = 'Titolo de 3-a nivelo';
$lang['qb_h4']                 = 'Titolo de 4-a nivelo';
$lang['qb_h5']                 = 'Titolo de 5-a nivelo';
$lang['qb_h']                  = 'Ĉeftitolo';
$lang['qb_hs']                 = 'Elektu ĉeftitolon';
$lang['qb_hplus']              = 'Altnivela titolo';
$lang['qb_hminus']             = 'Subnivela titolo';
$lang['qb_hequal']             = 'Samnivela titolo';
$lang['qb_link']               = 'Interna ligilo';
$lang['qb_extlink']            = 'Ekstera ligilo';
$lang['qb_hr']                 = 'Horizontala streko';
$lang['qb_ol']                 = 'Elemento de numerita listo';
$lang['qb_ul']                 = 'Elemento de ne numerita listo';
$lang['qb_media']              = 'Aldoni bildojn kaj aliajn dosierojn';
$lang['qb_sig']                = 'Inkluzivi subskribon';
$lang['qb_smileys']            = 'Ridetuloj';
$lang['qb_chars']              = 'Specialaj signaĵoj';
$lang['upperns']               = 'saltu al la parenca nomspaco';
$lang['admin_register']        = 'Aldoni novan uzanton';
$lang['metaedit']              = 'Redakti metadatumaron';
$lang['metasaveerr']           = 'La konservo de metadatumaro malsukcesis';
$lang['metasaveok']            = 'La metadatumaro konserviĝis';
$lang['img_title']             = 'Titolo';
$lang['img_caption']           = 'Priskribo';
$lang['img_date']              = 'Dato';
$lang['img_fname']             = 'Dosiernomo';
$lang['img_fsize']             = 'Grandeco';
$lang['img_artist']            = 'Fotisto';
$lang['img_copyr']             = 'Kopirajtoj';
$lang['img_format']            = 'Formato';
$lang['img_camera']            = 'Kamerao';
$lang['img_keywords']          = 'Ŝlosilvortoj';
$lang['img_width']             = 'Larĝeco';
$lang['img_height']            = 'Alteco';
$lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
$lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
$lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
$lang['subscr_unsubscribe_success'] = 'Forigis %s de la abonlisto por %s';
$lang['subscr_unsubscribe_error'] = 'Eraro dum forigo de %s de la abonlisto por %s';
$lang['subscr_already_subscribed'] = '%s jam estas abonanta al %s';
$lang['subscr_not_subscribed'] = '%s ne abonas al %s';
$lang['subscr_m_not_subscribed'] = 'Momente vi ne abonas la aktualan paĝon aŭ nomspacon.';
$lang['subscr_m_new_header']   = 'Aldoni abonon';
$lang['subscr_m_current_header'] = 'Momentaj abonoj';
$lang['subscr_m_unsubscribe']  = 'Malaboni';
$lang['subscr_m_subscribe']    = 'Aboni';
$lang['subscr_m_receive']      = 'Ricevi';
$lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
$lang['subscr_style_digest']   = 'resuma retpoŝtaĵo de ŝanĝoj por ĉiu paĝo (je %.2f tagoj)';
$lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo (je %.2f tagoj)';
$lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
$lang['authpwdexpire']         = 'Via pasvorto malvalidos post %d tagoj, prefere ŝanĝu ĝin baldaũ.';
$lang['i_chooselang']          = 'Elektu vian lingvon';
$lang['i_installer']           = 'Instalilo de DokuWiki';
$lang['i_wikiname']            = 'Nomo de la vikio';
$lang['i_enableacl']           = 'Ebligi "ACL" (alirkontrolo, rekomendinde)';
$lang['i_superuser']           = 'Superuzanto';
$lang['i_problems']            = 'La instalilo trovis kelkajn problemojn, indikitaj sube. Vi ne povas pluiri ĝis ili estos iel korektitaj.';
$lang['i_modified']            = 'Pro sekureco tiu ĉi instalilo nur funkcias por nova kaj nemodifita DokuWiki-pakaĵo.
Vi devas aŭ redemeti la dosierojn el la elŝutita pakaĵo aŭ plibone informiĝi pri la instalada procezo.';
$lang['i_funcna']              = 'La PHP-a funkcio <code>%s</code> ne estas uzebla. Eble via retprovizanto ial malpermesis tion?';
$lang['i_phpver']              = 'La versio de la PHP <code>%s</code> estas pli malnova ol la bezonata <code>%s</code>. Vi bezonas ĝisdatigi la PHP-an instalon.';
$lang['i_permfail']            = '<code>%s</code> ne estas skribebla por DokuWiki. Vi devas redifini la permes-atributojn de tiu ĉi dosierujo!';
$lang['i_confexists']          = '<code>%s</code> jam ekzistas';
$lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>". Vi bezonas kontroli la permesojn de la dosier(uj)oj kaj mem krej la dosieron.';
$lang['i_badhash']             = 'dokuwiki.php ne estas rekonebla aŭ ĝi estas modifita (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - malvalida aŭ malplena valoro';
$lang['i_success']             = 'La agordado sukcese kompletiĝis. Vi povas forigi la dosieron nun. Pluiru al <a href="doku.php?id=wiki:welcome">via nova DokuWiki</a>.';
$lang['i_failure']             = 'Kelkaj eraroj okazis dum la konservo de la agordaj dosieroj. Vi devas senpere korekti ilin antaŭ ol vi povos uzi <a href="doku.php?id=wiki:welcome">vian novan DokuWiki-on</a>.                       ';
$lang['i_policy']              = 'Komenca ACL-a agordo';
$lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
$lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
$lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
$lang['i_allowreg']            = 'Permesi al uzantoj registri sin mem';
$lang['i_retry']               = 'Reprovi';
$lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
$lang['i_license_none']        = 'Ne montri licencinformojn';
$lang['i_pop_field']           = 'Bonvolu helpi nin plibonigi la DokuWiki-sperton:';
$lang['i_pop_label']           = 'Sendi unufoje monate anonimajn datumojn pri la uzo al la DokuWiki-evoluigantoj';
$lang['recent_global']         = 'Vi nun rigardas la ŝanĝojn ene de la nomspaco <b>%s</b>. Vi povas ankaŭ <a href="%s">vidi la freŝajn ŝanĝojn de la tuta vikio</a>.';
$lang['years']                 = 'antaŭ %d jaroj';
$lang['months']                = 'antaŭ %d monatoj';
$lang['weeks']                 = 'antaŭ %d semajnoj';
$lang['days']                  = 'antaŭ %d tagoj';
$lang['hours']                 = 'antaŭ %d horoj';
$lang['minutes']               = 'antaŭ %d minutoj';
$lang['seconds']               = 'antaŭ %d sekundoj';
$lang['wordblock']             = 'Via ŝanĝo ne konserviĝis, ĉar ĝi enhavas blokitan tekston (spamon).';
$lang['media_uploadtab']       = 'Alŝuto';
$lang['media_searchtab']       = 'Serĉo';
$lang['media_file']            = 'Dosiero';
$lang['media_viewtab']         = 'Rigardi';
$lang['media_edittab']         = 'Modifi';
$lang['media_historytab']      = 'Historio';
$lang['media_list_thumbs']     = 'Bildeto';
$lang['media_list_rows']       = 'Kolumnoj';
$lang['media_sort_name']       = 'per nomo';
$lang['media_sort_date']       = 'per dato';
$lang['media_namespaces']      = 'Elektu nomspacon';
$lang['media_files']           = 'Dosieroj en %s';
$lang['media_upload']          = 'Alŝuti al la nomspaco <strong>%s</strong>.';
$lang['media_search']          = 'Serĉi en la nomspaco <strong>%s</strong>.';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s ĉe %s';
$lang['media_edit']            = 'Modifi %s';
$lang['media_history']         = 'Protokolo de %s';
$lang['media_meta_edited']     = 'metadatumoj ŝanĝitaj';
$lang['media_perm_read']       = 'Bedaûrinde viaj rajtoj ne sufiĉas por legi dosierojn.';
$lang['media_perm_upload']     = 'Bedaûrinde viaj rajtoj ne sufiĉas por alŝuti dosierojn.';
$lang['media_update']          = 'Alŝuti novan version';
$lang['media_restore']         = 'Restarigi ĉi tiun version';
$lang['currentns']             = 'Aktuala nomspaco';
$lang['searchresult']          = 'Serĉrezulto';
$lang['plainhtml']             = 'Plena HTML';
$lang['wikimarkup']            = 'Vikiteksto';
